==> MediaWikiLanguageExtensionBundle-2015.08.tar.bz2: extensions/cldr/CldrNames/CldrNamesEs_mx.php <==
<?php

$languageNames = array(
	'ba' => 'bashkir',
);

$currencyNames = array(
	'AFN' => 'afgani afgano',
	'ALL' => 'lek albanés',
	'AMD' => 'dram armenio',
	'AOA' => 'kwanza angoleño',
	'BDT' => 'taka de Bangladesh',
	'BND' => 'dólar de Brunéi',
	'BTN' => 'ngultrum butanés',
	'BWP' => 'pula botsuano',
	'CNY' => 'yuan chino',
	'ERN' => 'nakfa eritreo',
	'ETB' => 'birr etíope',
	'GEL' => 'lari georgiano',
	'GHS' => 'cedi ghanés',
	'GMD' => 'dalasi gambiano',
	'HKD' => 'dólar de Hong Kong',
	'HRK' => 'kuna croata',
	'ILS' => 'nuevo shéquel israelí',
	'JPY' => 'yen japonés',
	'KGS' => 'som kirguís',
	'KHR' => 'riel camboyano',
	'KZT' => 'tenge kazajo',
	'LAK' => 'kip laosiano',
	'LKR' => 'rupia de Sri Lanka',
	'LVL' => 'lats letón',
	'MGA' => 'ariary malgache',
	'MMK' => 'kyat de Myanmar',
	'MNT' => 'tugrik mongol',
	'MRO' => 'ouguiya mauritano',
	'MVR' => 'rufiyaa de Maldivas',
	'MWK' => 'kwacha malauí',
	'MYR' => 'ringgit malayo',
	'MZN' => 'metical mozambiqueño',
	'NGN' => 'naira nigeriano',
	'PGK' => 'kina de Papúa Nueva Guinea',
	'PLN' => 'zloty polaco',
	'QAR' => 'riyal de Qatar',
	'RON' => 'leu rumano',
	'SAR' => 'riyal saudí',
	'SBD' => 'dólar de las Islas Salomón',
	'SCR' => 'rupia de Seychelles',
	'SLL' => 'leone de Sierra Leona',
	'STD' => 'dobra de Santo Tomé y Príncipe',
	'SZL' => 'lilangeni suazi',
	'THB' => 'baht tailandés',
	'TMT' => 'manat turkmeno',
	'TOP' => 'paʻanga tongano',
	'UAH' => 'grivna ucraniana',
	'UZS' => 'som uzbeko',
	'VND' => 'dong vietnamita',
	'VUV' => 'vatu vanuatuense',
	'WST' => 'tala samoano',
	'ZAR' => 'rand sudafricano',
	'ZMW' => 'kwacha zambiano',
);

$currencySymbols = array(
	'AFN' => 'Af',
	'AOA' => 'Kz',
	'CNY' => 'CN¥',
);

$countryNames = array(
	'BD' => 'Bangladesh',
	'CC' => 'Islas Cocos (Keeling)',
	'CX' => 'Isla de Navidad',
	'GB' => 'RU',
	'GG' => 'Guernsey',
	'HK' => 'Región Administrativa Especial de Hong Kong de la República Popular China',
	'IC' => 'Islas Canarias',
	'MO' => 'Región Administrativa Especial de Macao de la República Popular China',
	'PW' => 'Palaos',
	'QO' => 'Islas Ultramarinas',
	'TA' => 'Tristán de Acuña',
	'UM' => 'Islas Ultramarinas Menores de Estados Unidos',
	'VI' => 'Islas Vírgenes de los Estados Unidos',
);

$timeUnits = array(
	'day-narrow-future-one' => '+{0} día',
	'day-narrow-future-other' => '+{0} días',
	'day-narrow-past-one' => '-{0} día',
	'day-narrow-past-other' => '-{0} días',
	'day-short-future-one' => 'en {0} día',
	'day-short-future-other' => 'en {0} días',
	'hour-narrow-future-one' => '+{0} h',
	'hour-narrow-future-other' => '+{0} h',
	'hour-narrow-past-one' => '-{0} h',
	'hour-narrow-past-other' => '-{0} h',
	'hour-short-future-one' => 'en {0} h',
	'hour-short-future-other' => 'en {0} n',
	'minute-narrow-future-one' => '+{0} min',
	'minute-narrow-future-other' => '+{0} min',
	'minute-narrow-past-one' => '-{0} min',
	'minute-narrow-past-other' => '-{0} min',
	'minute-short-future-one' => 'en {0} min',
	'minute-short-future-other' => 'en {0} min',
	'month-future-one' => 'en {0} mes',
	'month-future-other' => 'en {0} meses',
	'month-narrow-future-one' => '+{0} m',
	'month-narrow-future-other' => '+{0} m',
	'month-narrow-past-one' => '-{0} m',
	'month-narrow-past-other' => '-{0} m',
	'month-short-future-one' => 'en {0} m',
	'month-short-future-other' => 'en {0} m',
	'quarter-future-one' => 'en {0} trimestre',
	'quarter-future-other' => 'en {0} trimestres',
	'quarter-narrow-future-one' => '+{0} T',
	'quarter-narrow-future-other' => '+{0} T',
	'quarter-narrow-past-one' => '-{0} T',
	'quarter-narrow-past-other' => '-{0} T',
	'quarter-short-future-one' => 'en {0} trim.',
	'quarter-short-future-other' => 'en {0} trim',
	'second-narrow-future-one' => '+{0} s',
	'second-narrow-future-other' => '+{0} s',
	'second-narrow-past-one' => '-{0} s',
	'second-narrow-past-other' => '-{0} s',
	'second-short-future-one' => 'en {0} s',
	'second-short-future-other' => 'en {0} s',
	'week-narrow-future-one' => '+{0} sem.',
	'week-narrow-future-other' => '+{0} sem.',
	'week-narrow-past-one' => '-{0} sem.',
	'week-narrow-past-other' => '-{0} sem.',
	'week-short-future-one' => 'en {0} sem.',
	'week-short-future-other' => 'en {0} sem.',
	'year-narrow-future-one' => 'en {0} a',
	'year-narrow-future-other' => 'en {0} a',
	'year-narrow-past-one' => '-{0} a',
	'year-narrow-past-other' => '-{0} a',
	'year-short-future-one' => 'en {0} a',
	'year-short-future-other' => 'en {0} a',
);

==> MediaWikiLanguageExtensionBundle-2016.04.tar.bz2: extensions/cldr/CldrNames/CldrNamesEs_mx.php <==
<?php

$languageNames = [
	'ba' => 'bashkir',
];

$currencyNames = [
	'AFN' => 'afgani afgano',
	'ALL' => 'lek albanés',
	'AMD' => 'dram armenio',
	'AOA' => 'kwanza angoleño',
	'BDT' => 'taka de Bangladesh',
	'BND' => 'dólar de Brunéi',
	'BTN' => 'ngultrum butanés',
	'BWP' => 'pula botsuano',
	'CNY' => 'yuan chino',
	'ERN' => 'nakfa eritreo',
	'ETB' => 'birr etíope',
	'GEL' => 'lari georgiano',
	'GHS' => 'cedi ghanés',
	'GMD' => 'dalasi gambiano',
	'HKD' => 'dólar de Hong Kong',
	'HRK' => 'kuna croata',
	'ILS' => 'nuevo shéquel israelí',
	'JPY' => 'yen japonés',
	'KGS' => 'som kirguís',
	'KHR' => 'riel camboyano',
	'KZT' => 'tenge kazajo',
	'LAK' => 'kip laosiano',
	'LKR' => 'rupia de Sri Lanka',
	'LVL' => 'lats letón',
	'MGA' => 'ariary malgache',
	'MMK' => 'kyat de Myanmar',
	'MNT' => 'tugrik mongol',
	'MRO' => 'ouguiya mauritano',
	'MVR' => 'rufiyaa de Maldivas',
	'MWK' => 'kwacha malauí',
	'MYR' => 'ringgit malayo',
	'MZN' => 'metical mozambiqueño',
	'NGN' => 'naira nigeriano',
	'PGK' => 'kina de Papúa Nueva Guinea',
	'PLN' => 'zloty polaco',
	'QAR' => 'riyal de Qatar',
	'RON' => 'leu rumano',
	'SAR' => 'riyal saudí',
	'SBD' => 'dólar de las Islas Salomón',
	'SCR' => 'rupia de Seychelles',
	'SLL' => 'leone de Sierra Leona',
	'STD' => 'dobra de Santo Tomé y Príncipe',
	'SZL' => 'lilangeni suazi',
	'THB' => 'baht tailandés',
	'TMT' => 'manat turkmeno',
	'TOP' => 'paʻanga tongano',
	'UAH' => 'grivna ucraniana',
	'UZS' => 'som uzbeko',
	'VND' => 'dong vietnamita',
	'VUV' => 'vatu vanuatuense',
	'WST' => 'tala samoano',
	'ZAR' => 'rand sudafricano',
	'ZMW' => 'kwacha zambiano',
];

$currencySymbols = [
	'AFN' => 'Af',
	'AOA' => 'Kz',
	'CNY' => 'CN¥',
];

$countryNames = [
	'BD' => 'Bangladesh',
	'CC' => 'Islas Cocos (Keeling)',
	'CX' => 'Isla de Navidad',
	'GB' => 'RU',
	'GG' => 'Guernsey',
	'HK' => 'Región Administrativa Especial de Hong Kong de la República Popular China',
	'IC' => 'Islas Canarias',
	'MO' => 'Región Administrativa Especial de Macao de la República Popular China',
	'PW' => 'Palaos',
	'QO' => 'Islas Ultramarinas',
	'TA' => 'Tristán de Acuña',
	'UM' => 'Islas Ultramarinas Menores de Estados Unidos',
	'VI' => 'Islas Vírgenes de los Estados Unidos',
];

$timeUnits = [
	'day-narrow-future-one' => '+{0} día',
	'day-narrow-future-other' => '+{0} días',
	'day-narrow-past-one' => '-{0} día',
	'day-narrow-past-other' => '-{0} días',
	'day-short-future-one' => 'en {0} día',
	'day-short-future-other' => 'en {0} días',
	'hour-narrow-future-one' => '+{0} h',
	'hour-narrow-future-other' => '+{0} h',
	'hour-narrow-past-one' => '-{0} h',
	'hour-narrow-past-other' => '-{0} h',
	'hour-short-future-one' => 'en {0} h',
	'hour-short-future-other' => 'en {0} n',
	'minute-narrow-future-one' => '+{0} min',
	'minute-narrow-future-other' => '+{0} min',
	'minute-narrow-past-one' => '-{0} min',
	'minute-narrow-past-other' => '-{0} min',
	'minute-short-future-one' => 'en {0} min',
	'minute-short-future-other' => 'en {0} min',
	'month-future-one' => 'en {0} mes',
	'month-future-other' => 'en {0} meses',
	'month-narrow-future-one' => '+{0} m',
	'month-narrow-future-other' => '+{0} m',
	'month-narrow-past-one' => '-{0} m',
	'month-narrow-past-other' => '-{0} m',
	'month-short-future-one' => 'en {0} m',
	'month-short-future-other' => 'en {0} m',
	'quarter-future-one' => 'en {0} trimestre',
	'quarter-future-other' => 'en {0} trimestres',
	'quarter-narrow-future-one' => '+{0} T',
	'quarter-narrow-future-other' => '+{0} T',
	'quarter-narrow-past-one' => '-{0} T',
	'quarter-narrow-past-other' => '-{0} T',
	'quarter-short-future-one' => 'en {0} trim.',
	'quarter-short-future-other' => 'en {0} trim',
	'second-narrow-future-one' => '+{0} s',
	'second-narrow-future-other' => '+{0} s',
	'second-narrow-past-one' => '-{0} s',
	'second-narrow-past-other' => '-{0} s',
	'second-short-future-one' => 'en {0} s',
	'second-short-future-other' => 'en {0} s',
	'week-narrow-future-one' => '+{0} sem.',
	'week-narrow-future-other' => '+{0} sem.',
	'week-narrow-past-one' => '-{0} sem.',
	'week-narrow-past-other' => '-{0} sem.',
	'week-short-future-one' => 'en {0} sem.',
	'week-short-future-other' => 'en {0} sem.',
	'year-narrow-future-one' => 'en {0} a',
	'year-narrow-future-other' => 'en {0} a',
	'year-narrow-past-one' => '-{0} a',
	'year-narrow-past-other' => '-{0} a',
	'year-short-future-one' => 'en {0} a',
	'year-short-future-other' => 'en {0} a',
];
